HttpClient

Struct HttpClient 

pub struct HttpClient { /* private fields */ }
An HTTP client.

Implementations

Source

impl HttpClient

pub fn builder() -> HttpClientBuilder

Creates a new builder for configuring an HTTP client.

pub async fn send<B>( &mut self, req: Request<B>, ) -> Result<Response<Incoming>, GenericError>
where B: Body + Send + Sync + 'static, B::Data: Buf + Send, B::Error: Into<Box<dyn Error + Send + Sync>>,

Sends a request to the server, and waits for a response.

The request body is type-erased internally, so callers can use any body type that implements Body with Data types that implement Buf.

Errors

If there was an error sending the request, an error will be returned.