pub struct HttpsCapableConnectorBuilder { /* private fields */ }Expand description
A builder for HttpsCapableConnector.
Implementations
Sourceimpl HttpsCapableConnectorBuilder
impl HttpsCapableConnectorBuilder
Sourcepub fn with_connect_timeout(self, timeout: Duration) -> Self
pub fn with_connect_timeout(self, timeout: Duration) -> Self
Sets the timeout when connecting to the remote host.
Defaults to 30 seconds.
Sourcepub fn with_connection_age_limit<L>(self, limit: L) -> Self
pub fn with_connection_age_limit<L>(self, limit: L) -> Self
Sets the maximum age of a connection before it is closed.
This is distinct from the maximum idle time: if any connection’s age exceeds limit, it will be closed rather
than being reused and added to the idle connection pool.
Defaults to no limit.
Sourcepub fn with_bytes_sent_counter(self, counter: Counter) -> Self
pub fn with_bytes_sent_counter(self, counter: Counter) -> Self
Sets a counter that gets incremented with the number of bytes sent over the connection.
This tracks bytes sent at the HTTP client level, which includes headers and body but does not include underlying transport overhead, such as TLS handshaking, and so on.
Defaults to unset.
Sourcepub fn with_unix_socket_path<P: Into<PathBuf>>(self, path: P) -> Self
pub fn with_unix_socket_path<P: Into<PathBuf>>(self, path: P) -> Self
Sets a Unix domain socket path to route all connections through.
When set, the connector will connect to this Unix socket instead of performing DNS resolution and TCP connection. The URI host is ignored in this case — all requests are sent through the configured socket.
Defaults to unset (TCP connections via DNS).
Sourcepub fn build(
self,
tls_config: ClientConfig,
) -> Result<HttpsCapableConnector, GenericError>
pub fn build( self, tls_config: ClientConfig, ) -> Result<HttpsCapableConnector, GenericError>
Builds the HttpsCapableConnector from the given TLS configuration.